@@ -7,9 +7,14 @@
 # it under the terms of the GPLv3 license; see LICENSE file for more details.
 """cernopendata-client version test."""
 
+from cernopendata_client import __version__
+from click.testing import CliRunner
+from cernopendata_client.cli import version
+
 
 def test_version():
     """Test version import."""
-    from cernopendata_client import __version__
-
-    assert __version__
+    test_version = CliRunner()
+    test_result = test_version.invoke(version)
+    assert test_result.exit_code == 0
+    assert test_result.output == __version__ + "\n"
